/*
 * rootapps main graphics functions
 */

#ifndef ROOTAPPS_H
#define ROOTAPPS_H

#include <X11/Xlib.h>
#include <X11/Xutil.h>
#include <X11/Xatom.h>

typedef struct {
    Window     window;
    Pixmap     rootpixmap;
    Pixmap     bgpixmap;
    XSizeHints wsize;
} RootApp;


Display   *display;
GC         gc;


/* colors */
unsigned long get_color(const char *color_name);
void set_color(const char *color_name);


/* fonts */
void load_font(const char *font_name);
int font_height();
int font_ascent();
int font_descent();
int text_width(const char *text);


/* Pixmaps and drawings */
Pixmap copy_pixmap(RootApp *app, Pixmap source);
Pixmap root_pixmap(const char *desc);
Pixmap get_root_pixmap(RootApp *app);
void pixmap_to_app(RootApp *app, Pixmap source,
        int srcx, int srcy, int width, int height, int destx, int desty);
void draw_line(RootApp *app, int x1, int y1, int x2, int y2);


/* clean before exit program */
void clean_window(RootApp *app);

/* Windows / apps manipulations */
void clear_bg(RootApp *app);
void display_app(RootApp *app);
void root_print(RootApp *app, char *data, int x, int y);

/* create_app : mask == event mask, text == default text for size computing */
RootApp *create_app(const char *displayname, int mask,
        const char *geometry, const char *fontname, const char *text);

void close_app(RootApp *app);

/* Events */
int nextevent_or_timeout(XEvent *event, unsigned long miliseconds);

#endif
